/*
 * dumpbw.c - Interpret a file as a grayscale image, whether it really
 *	is or not.  Useful for finding graphics within other files.
 *	This is not intended for copyright infringement.
 *
 * Copyright 2000, George Greer <greerga@muc.muohio.edu>
 *
 * Licensed under the GNU General Public License (GPL)
 *
 *   This program is free software; you can redistribute it and/or modify
 *   it under the terms of the GNU General Public License as published by
 *   the Free Software Foundation; either version 2 of the License, or
 *   (at your option) any later version.
 *
 *   This program is distributed in the hope that it will be useful,
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *   GNU General Public License for more details.
 *
 *   You should have received a copy of the GNU General Public License
 *   along with this program; if not, write to the Free Software
 *   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
 *   or visit ftp://ftp.gnu.org/pub/gnu/COPYING via the Internet.
 */

#include <stdio.h>
#include <stdlib.h>
#include <gd.h>

#include "mmaplib.h"

const char *copyright = "dumpbw.c: Copyright 2000, George Greer <greerga@muc.muohio.edu>";
const char *version = "v0.1 (Build: "__DATE__" "__TIME__")";

void writepicture(const char *outfile, const unsigned char *data, size_t length, int blocksize);

int main(int argc, char *argv[])
{
  char *infile, *outfile;
  int blocklen;
  void *handle;

  if (argc < 4) {
    printf("Usage: %s block-length input-file output-file\n", argv[0]);
    return 1;
  }

  blocklen = atoi(argv[1]);
  infile = argv[2];
  outfile = argv[3];

  if (blocklen <= 0)
    error("invalid block length");

  if (!(handle = mapopen(infile)))
    return 1;
  writepicture(outfile, mapdata(handle), maplength(handle), blocklen);
  mapclose(handle);

  return 0;
}

void writepicture(const char *outfile, const unsigned char *data, size_t length, int blocksize)
{
  gdImagePtr pic;
  int itr;
  FILE *output;

  pic = gdImageCreate(blocksize, (int)((length / blocksize) + 0.5));

  if (!(output = fopen(outfile, "wb")))
    error(outfile);

  for (itr = 0; itr < length; itr++) {
    int x1, y1, x2, y2, cr;
  
    x1 = itr % blocksize;
    y1 = itr / blocksize;
    x2 = x1 + blocksize;
    y2 = y1 + 1;

    if ((cr = gdImageColorExact(pic, data[itr], data[itr], data[itr])) < 0)
      if ((cr = gdImageColorAllocate(pic, data[itr], data[itr], data[itr])) < 0)
        error("ran out of colors");

    gdImageFilledRectangle(pic, x1, y1, x2, y2, cr);
  }

  gdImageGif(pic, output);
  fclose(output);
  gdImageDestroy(pic);
}
